Type Alias ItemRef
Source pub type ItemRef = &'static Item;
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.